# config editor

![screenshot](../sample/managager_screenshot.JPG)

The plugin editor lets you override pyblish plugin settings externally.  
The aim is to assist with pipeline configuration and promote sharing and reusing plugins.  
